==> igniteui-angular-charts-16.0.0.tgz: package/esm5/lib/OnBalanceVolumeIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { OnBalanceVolumeIndicatorStrategy } from "./OnBalanceVolumeIndicatorStrategy";
import { markType } from "igniteui-angular-core";
/**
 * @hidden
 */
var OnBalanceVolumeIndicator = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(OnBalanceVolumeIndicator, _super);
    function OnBalanceVolumeIndicator() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    OnBalanceVolumeIndicator.prototype.get_ul = function () {
        return new OnBalanceVolumeIndicatorStrategy();
    };
    Object.defineProperty(OnBalanceVolumeIndicator.prototype, "ul", {
        get: function () {
            return this.get_ul();
        },
        enumerable: false,
        configurable: true
    });
    OnBalanceVolumeIndicator.prototype.get_uy = function () {
        return OnBalanceVolumeIndicator.$;
    };
    Object.defineProperty(OnBalanceVolumeIndicator.prototype, "uy", {
        get: function () {
            return this.get_uy();
        },
        enumerable: false,
        configurable: true
    });
    OnBalanceVolumeIndicator.$t = markType(OnBalanceVolumeIndicator, 'OnBalanceVolumeIndicator', StrategyBasedIndicator.$);
    return OnBalanceVolumeIndicator;
}(StrategyBasedIndicator));
export { OnBalanceVolumeIndicator };

==> igniteui-angular-charts-17.2.1.tgz: package/esm5/lib/OnBalanceVolumeIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { OnBalanceVolumeIndicatorStrategy } from "./OnBalanceVolumeIndicatorStrategy";
import { markType } from "igniteui-angular-core";
/**
 * @hidden
 */
var OnBalanceVolumeIndicator = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(OnBalanceVolumeIndicator, _super);
    function OnBalanceVolumeIndicator() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    OnBalanceVolumeIndicator.prototype.bg = function () {
        return new OnBalanceVolumeIndicator();
    };
    OnBalanceVolumeIndicator.prototype.get_yz = function () {
        return new OnBalanceVolumeIndicatorStrategy();
    };
    Object.defineProperty(OnBalanceVolumeIndicator.prototype, "yz", {
        get: function () {
            return this.get_yz();
        },
        enumerable: false,
        configurable: true
    });
    OnBalanceVolumeIndicator.prototype.get_zc = function () {
        return OnBalanceVolumeIndicator.$;
    };
    Object.defineProperty(OnBalanceVolumeIndicator.prototype, "zc", {
        get: function () {
            return this.get_zc();
        },
        enumerable: false,
        configurable: true
    });
    OnBalanceVolumeIndicator.$t = markType(OnBalanceVolumeIndicator, 'OnBalanceVolumeIndicator', StrategyBasedIndicator.$);
    return OnBalanceVolumeIndicator;
}(StrategyBasedIndicator));
export { OnBalanceVolumeIndicator };
